@@ -2,9 +2,10 @@ import json
 import logging
 import platform
 
-from django.core.serializers.json import DjangoJSONEncoder
 from django.http import UnreadablePostError
 
+from chamber.utils.json import ChamberJSONEncoder
+
 
 def skip_unreadable_post(record):
     if record.exc_info:
@@ -29,8 +30,7 @@ class AppendExtraJSONHandler(logging.StreamHandler):
             for k, v in record.__dict__.items()
             if k not in self.DEFAULT_STREAM_HANDLER_VARIABLE_KEYS.union(self.CUSTOM_STREAM_HANDLER_VARIABLE_KEYS)
         }
-        record.msg = '{} --- {}'.format(record.msg, json.dumps(extra, cls=DjangoJSONEncoder,
-                                        default=lambda x: '<<NON-SERIALIZABLE TYPE: {}>>'.format(type(x).__qualname__)))
+        record.msg = '{} --- {}'.format(record.msg, json.dumps(extra, cls=ChamberJSONEncoder))
         super().emit(record)
 
 
